Index: soft/giet_vm/giet_boot/boot.c
===================================================================
--- soft/giet_vm/giet_boot/boot.c	(revision 655)
+++ soft/giet_vm/giet_boot/boot.c	(revision 656)
@@ -1276,4 +1276,5 @@
                     psched->context[ltid][CTX_SR_ID]     = GIET_SR_INIT_VALUE;
                     psched->context[ltid][CTX_SP_ID]     = ctx_sp;
+                    psched->context[ltid][CTX_EPC_ID]    = ctx_entry;
                     psched->context[ltid][CTX_ENTRY_ID]  = ctx_entry;
                     psched->context[ltid][CTX_PTPR_ID]   = ctx_ptpr;
Index: soft/giet_vm/giet_kernel/kernel_init.c
===================================================================
--- soft/giet_vm/giet_kernel/kernel_init.c	(revision 655)
+++ soft/giet_vm/giet_kernel/kernel_init.c	(revision 656)
@@ -317,6 +317,6 @@
     ////////////////////////////////////////////////////////////////////////////
     // step 3 : - Each processor complete idle task context initialisation.
     //            Only CTX_SP, CTX_RA, CTX_EPC slots, because other slots
     //            have been initialised in boot code)
     //            The 4 Kbytes idle stack is implemented in the scheduler itself.
     //          - Each processor starts TICK timer, if at least one task.
@@ -332,4 +332,5 @@
     _set_task_slot( x , y , p , IDLE_TASK_INDEX , CTX_SP_ID  , sp    );
     _set_task_slot( x , y , p , IDLE_TASK_INDEX , CTX_RA_ID  , ra    );
+    _set_task_slot( x , y , p , IDLE_TASK_INDEX , CTX_EPC_ID , entry );
     _set_task_slot( x , y , p , IDLE_TASK_INDEX , CTX_ENTRY_ID , entry );
 
@@ -317,6 +317,6 @@
     ////////////////////////////////////////////////////////////////////////////
     // step 3 : - Each processor complete idle task context initialisation.
-    //            Only CTX_SP, CTX_RA, CTX_EPC slots, because other slots
-    //            have been initialised in boot code)
+    //            Only CTX_SP, CTX_RA, CTX_EPC, CTX_ENTRY slots, because other
+    //            slots have been initialised in boot code)
     //            The 4 Kbytes idle stack is implemented in the scheduler itself.
     //          - Each processor starts TICK timer, if at least one task.
